# -*- coding: utf-8 -*-

from django.conf import settings
from django.http import Http404
from django.shortcuts import get_object_or_404, redirect
from django.views.generic import TemplateView, View
from django.views.generic.base import RedirectView
from django.utils.html import strip_tags
from alapage.models import Page
from alapage.utils import can_see_page
from alapage.conf import USE_JSSOR, BASE_TEMPLATE_PATH, ENABLE_PRIVATE_PAGES
    

def get_template_to_extend():
    return BASE_TEMPLATE_PATH
 

class PageView(TemplateView):
    
    def dispatch(self, request, *args, **kwargs):
        # get the page
        try:
            url = kwargs['url']
        except:
            url = '/'
        if not url.startswith('/'):
            url = '/' + url
        if not url.endswith('/') and settings.APPEND_SLASH:
            url += '/'
        if ENABLE_PRIVATE_PAGES is True:
            self.page = get_object_or_404(Page.objects.prefetch_related('groups_only', 'users_only'), url=url)
        else:
            self.page = get_object_or_404(Page.objects.select_related(), url=url)
        # check permissions
        if ENABLE_PRIVATE_PAGES is True:
            if can_see_page(self.page, request.user) is False:
                raise Http404
        return super(PageView, self).dispatch(request, *args, **kwargs)
    
    def get_template_names(self):
        template_name = 'alapage/default.html'
        if self.page.template_name:
            template_name=self.page.template_name
        return [template_name]
    
    def get_context_data(self, **kwargs):
        context = super(PageView, self).get_context_data(**kwargs)
        page=self.page
        if not page.published and not self.request.user.is_superuser:
            raise Http404
        layout=self.page.layout
        if page.breakpoints_with_no_header:
            bnh = []
            for bp in page.breakpoints_with_no_header.split(','):
                bnh.append(int(str.rstrip(str(bp)))) 
            context['breakpoints_with_no_header'] = bnh
            print str(context['breakpoints_with_no_header'])
        context['page'] = page
        context['layout'] = layout
        context['layout_path'] = 'alapage/layouts/'+layout+'/top.html'
        context['template_to_extend'] = get_template_to_extend()
        return context


class HomepageView(PageView):
    pass



    
    


# -*- coding: utf-8 -*-

from django import forms
from django.conf import settings
from django.utils.translation import ugettext_lazy as _
from codemirror2.widgets import CodeMirrorEditor
from ckeditor_uploader.widgets import CKEditorUploadingWidget
from alapage.models import Page
from alapage.conf import EDIT_MODE, CODEMIRROR_KEYMAP, USE_JSSOR


class PageAdminForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super(PageAdminForm, self).__init__(*args, **kwargs)
        try:
            self.fields['template_name'].help_text = _(u'If no template is defined neither any layout, "alapage/default.html" will be used' )
        except:
            pass
    
    if EDIT_MODE == 'visual':    
        content = forms.CharField(widget=CKEditorUploadingWidget())
    elif EDIT_MODE == 'code':
        content = forms.CharField(
                                  widget=CodeMirrorEditor(options={
                                                             'mode':'htmlmixed',
                                                             'width':'1170px',
                                                             'indentWithTabs':'true', 
                                                             #'indentUnit' : '4',
                                                             'lineNumbers':'true',
                                                             'autofocus':'true',
                                                             #'highlightSelectionMatches': '{showToken: /\w/, annotateScrollbar: true}',
                                                             'styleActiveLine': 'true',
                                                             'autoCloseTags': 'true',
                                                             'keyMap': CODEMIRROR_KEYMAP,
                                                             'theme':'blackboard',
                                                             }, 
                                                             modes=['css', 'xml', 'javascript', 'htmlmixed'],
                                                             )
                                  
                                  )
    else:
        content = forms.CharField(widget=forms.Textarea)
    content.required = False
    
    class Meta:
        model = Page
        exclude = ('enable_comments','sites')



# -*- coding: utf-8 -*-

from django.db import models
from django.conf import settings
from django.utils.translation import ugettext_lazy as _
from django.contrib.flatpages.models import FlatPage
from django.contrib.auth.models import Group 
from ckeditor.fields import RichTextField
from alapage.conf import USER_MODEL, USE_JSSOR, LAYOUTS


class Seo(models.Model):
    seo_description = models.CharField(max_length=256, null=True, blank=True, verbose_name=_(u'SEO: description'), help_text=_(u'Short description of the page content'))
    seo_keywords = models.CharField(max_length=120, null=True, blank=True, verbose_name=_(u'SEO: keywords'), help_text=_(u'List of keywords separated by commas'))

    class Meta:
        abstract = True
        verbose_name=_(u'SEO')


class BasePage(FlatPage, Seo):
    class Meta:
        abstract = True


class Page(BasePage):
    layout = models.CharField(null=True, blank=True, max_length=125, choices=LAYOUTS, default=LAYOUTS[0][0], help_text=_(u'Note: the field name of the template takes precedence over layout choices'))
    edited = models.DateTimeField(editable=False, null=True, auto_now=True, verbose_name=_(u'Edited'))
    created = models.DateTimeField(editable=False, null=True, auto_now_add=True, verbose_name=_(u'Created'))
    editor = models.ForeignKey(USER_MODEL, editable = False, related_name='+', null=True, on_delete=models.SET_NULL, verbose_name=_(u'Edited by'))   
    published = models.BooleanField(default='published', verbose_name=_(u'Published'))
    staff_only = models.BooleanField(default=False, verbose_name=_(u'Staff only'))
    superuser_only = models.BooleanField(default=False, verbose_name=_(u'Superuser only'))
    groups_only = models.ManyToManyField(Group, blank=True, verbose_name=_(u'Reserved to some groups'))
    users_only = models.ManyToManyField(USER_MODEL, blank=True, verbose_name=_(u'Reserved to some users')) 
    if USE_JSSOR:
        slideshow_group = models.SlugField(null=True, blank=True, verbose_name=_(u'Slideshows group id'))
        breakpoints_with_no_header = models.CharField(max_length=8, blank=True, verbose_name=_(u'Breakpoints fullscreen'), help_text=_(u'This will remove the {% header %} or {% site_header %} block to display a fullscreen slideshow/ Ex: 320, 360'))
    
    
    class Meta:
        verbose_name = _(u'Page')
        verbose_name_plural = _(u'Page')
        ordering = ['url']
        permissions = (
            ("can_change_page_permissions", "Can change page permissions"),
        )


# -*- coding: utf-8 -*-

from django.conf import settings
from django.contrib.auth.models import User


EDIT_MODES = (
              'visual',
              'mixed',
              'code',
              )

LAYOUTS = (('xs-12','Xs 12'),('smooth-md','Smooth md'))

USER_MODEL = getattr(settings, 'AUTH_USER_MODEL', User)

USE_JSSOR=getattr(settings, 'ALAPAGE_USE_JSSOR', False)
USE_REVERSION=getattr(settings, 'ALAPAGE_USE_REVERSION', False)

BASE_TEMPLATE_PATH = getattr(settings, 'ALAPAGE_BASE_TEMPLATE_PATH', 'base.html')

EDIT_MODE = getattr(settings, 'ALAPAGE_EDIT_MODE', EDIT_MODES[0])
CODEMIRROR_KEYMAP = getattr(settings, 'ALAPAGE_CODEMIRROR_KEYMAP', 'default')

ENABLE_PRIVATE_PAGES = getattr(settings, 'ALAPAGE_ENABLE_PRIVATE_PAGES', False)

